<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field</source>
        <translation>Kolonka</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field name</source>
        <translation>Název kolonky</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Field description</source>
        <translation>Popis kolonky</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Value</source>
        <translation>Hodnota</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Field value</source>
        <translation>Hodnota v kolonce</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Při zavření ukončit</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Zapamatovat si polohu</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Překládat IP adresy na názvy strojů</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Překládat čísla portů na názvy služeb</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>Šipky pro zobrazení (ovládací prvek)</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>Linky větve</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Při ukončování automaticky uložit nastavení</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Výběr: zkopírovat identif. procesů do schránky</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Normalizovat prioritu (NICE)</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Použít pro názvy map mapu procesů</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>Lineární</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>Strom</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>Vlákno</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>Všechny procesy</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>Vaše procesy</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Procesy nenáležející správci systému (root)</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>Spuštěné procesy</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pozastavit (Ctrl+mezerník)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Proces %1 ( %2 ) – podrobnosti</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Soubory</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Sokety</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Mapy paměti</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Prostředí</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Všechny kolonky</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable</source>
        <translation>Proměnná</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable name</source>
        <translation>Název proměnné</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Value</source>
        <translation>Hodnota</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Variable value</source>
        <translation>Hodnota v proměnné</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Vybrat uživatelem určené kolonky </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>Fd</source>
        <translation>Popis. soub.</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>File descriptor</source>
        <translation>Popisovač souboru</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Open mode</source>
        <translation>Režim otevírání</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>File name (if available)</source>
        <translation>Název souboru (pokud je k dispozici)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="785"/>
        <source>I/O Summary:</source>
        <translation>Souhrn vstupů/výstupů:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="819"/>
        <source>No input or output</source>
        <translation>Žádný vstup či výstup</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Změnit interval aktualizace</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Nový interval aktualizace</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>Neaktualizovat</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Neplatná hodnota</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Adresní rozsah</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Mapované adresy (šestnáctkově) )</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Mapováno kilobajtů (desítkově)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation>Oprávnění</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Příznaky oprávnění</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Posun</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Posun souboru na začátku mapování (šestnáctkově)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Zařízení</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Hlavní,vedlejší čísla zařízení (desítkově)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation>I-uzel</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Číslo i-uzlu (desítkově)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Název souboru (pokud je k dispozici)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Oprávnění</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Heslo správce systému</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>%procesoru děleno</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>Celkem procesorů: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>Jediný procesor: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>výchozí</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>pro vývojáře</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Písmo</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>PID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>Process ID</source>
        <translation>Identif. procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>TGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>Identif. skupiny úlohy (nadřazené vláknům)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>PPID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>Parent process ID</source>
        <translation>Identif. nadřazeného procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>PGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>Process group ID</source>
        <translation>Identif. skupiny procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>SID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>Session ID</source>
        <translation>Identif. sezení</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>TTY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>Terminal</source>
        <translation>Konzole</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>TPGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>Process group ID of tty owner</source>
        <translation>Identif. skupiny vlastníka konzole</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>USER</source>
        <translation>UŽIVATEL</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Vlastník (*=suid správce, +=suid uživatel)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>GROUP</source>
        <translation>SKUPINA</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>Group name (*=sgid other)</source>
        <translation>Název skupiny (*=sgid ostatní)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>UID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>Real user ID</source>
        <translation>identif. skutečného uživatele</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>EUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>Effective user ID</source>
        <translation>Efektivní identif. uživatele</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>SUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>Saved user ID (Posix)</source>
        <translation>Uložený identif. uživatele (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>FSUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>File system user ID</source>
        <translation>Identifikátor uživatele soubor. systému</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>GID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>Real group ID</source>
        <translation>Skutečný identif. skupiny</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>EGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>Effective group ID</source>
        <translation>Efektivní identif. skupiny</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>SGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>Saved group ID (Posix)</source>
        <translation>Uložený identif. skupiny (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>FSGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>File system group ID</source>
        <translation>Identif. skupiny souborového systému</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>PRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>Dynamic priority</source>
        <translation>Dynamická priorita</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>NICE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Přednost při plánování (vyšší -&gt; méně času procesoru)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>NLWP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Počet úloh (vláken) ve skupině úlohy</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>PLCY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>Scheduling policy</source>
        <translation>Zásada plánování</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>RPRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Priorita pro reálný čas (0-99, vyšší je lepší)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>TMS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>Time slice in milliseconds</source>
        <translation>Časové okno (v milisekundách)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>%SAVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Průměrné procento doby spánku (-1 -&gt; N/A)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>CPUSET</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Maska přiřazení procesoru CPU (0 -&gt; aplikační program. rozhraní není podporováno)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>MAJFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>Number of major faults (disk access)</source>
        <translation>Počet velkých nezdarů (přístup k disku)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>MINFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Počet drobných nezdarů (žádný přístup k disku)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>VSIZE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Virtual image size of process</source>
        <translation>Velikost virtuálního obrazu procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>RSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>Resident set size</source>
        <translation>Velikost rezidentní sady</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>využití paměti (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>TRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>Text(code) resident set size</source>
        <translation>Velikost rezidentní sady textu (kódu)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>DRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>Velikost rezidentní sady dat (přiřazení paměti + globální proměnná)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>STACK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>Stack size</source>
        <translation>Velikost zásobníku</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>SHARE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>Shared memory with other libs</source>
        <translation>Paměť sdílená s ostatními knihovnami</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>SWAP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>Kbytes on swap device</source>
        <translation>Kilobajtů na zařízení pro odkládání stránek paměti (swap)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>IO_R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>io read (file)</source>
        <translation>vst/výst. čtení (soubor)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>IO_W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>io write (file)</source>
        <translation>vst/výst. zápisu (soubor)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>DT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Počet nezapsaných („dirty“) stránek</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>STAT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>State of the process </source>
        <translation>Stav procesu </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>FLAGS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>Process flags (hex)</source>
        <translation>Příznaky procesu (šestnáctkově)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>WCHAN</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Funkce jádra kde proces spí</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>%WCPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Vážený průměr procent procesoru (za 30 s)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>%CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Procento využití procesoru od minulé aktualizace</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>%MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Procento využití paměti (RSS / celkem paměti)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>START</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>Time process started</source>
        <translation>Okamžik spuštění procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>TIME</source>
        <translation>DOBA</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>Total CPU time used since start</source>
        <translation>Celkový čas procesoru spotřebovaný od spuštění</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU</source>
        <translation>Procesor</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>Jádro procesoru na kterém je proces vykonáván</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>the process name</source>
        <translation>název procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>Process Name</source>
        <translation>Název procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>CWD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>Current working directory</source>
        <translation>Stávající pracovní složka</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>ROOT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>Root directory of process</source>
        <translation>Kořenová složka procesu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>COMMAND_LINE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Command line that started the process</source>
        <translation>Příkaz kterým byl proces spuštěn</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1618"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1621"/>
        <source>Hide</source>
        <translation>Skrýt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1626"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation>Uživatel: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation>Systém: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation>Priorita: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="509"/>
        <source>Total: </source>
        <translation>Celkem: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="477"/>
        <location filename="../infobar.cpp" line="515"/>
        <source>Used: </source>
        <translation>Využito: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Cached: </source>
        <translation>V mezipaměti: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="484"/>
        <source>Buffer: </source>
        <translation>Vyrovnávací paměť: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="512"/>
        <source>Free: </source>
        <translation>Volné: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="554"/>
        <source>Time passed after system boot</source>
        <translation>Čas uplynulý od startu systému</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="582"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation>Průměrné vytížení procesoru každých 1, 5, 15 minut</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="727"/>
        <source>CPU Usage Summary:</source>
        <translation>Souhrn vytížení procesoru:</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="171"/>
        <source>header_popup</source>
        <translation>vyskakovací hlavička</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="172"/>
        <source>Remove Field</source>
        <translation>Odebrat kolonku</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="173"/>
        <source>Add Field</source>
        <translation>Přidat kolonku</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Session</source>
        <translation>Relace</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="180"/>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="181"/>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="182"/>
        <source>Log</source>
        <translation>Záznam událostí (log)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="187"/>
        <source>Fields</source>
        <translation>Kolonky</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="188"/>
        <source>Custom Fields</source>
        <translation>Uživatelem určené kolonky</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Basic Fields </source>
        <translation>Základní kolonky </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="192"/>
        <source>Jobs Fields </source>
        <translation>Kolonky úloh </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="194"/>
        <source>Memory Fields </source>
        <translation>Kolonky paměti </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Scheduling Fields </source>
        <translation>Kolonky plánování </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Select Custom Fields...</source>
        <translation>Vybrat uživatelem určené kolonky…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="223"/>
        <source>Options</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Update Period...</source>
        <translation>Perioda aktualizace…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="233"/>
        <source>Show Status bar</source>
        <translation>Zobrazit stavový pruh</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="242"/>
        <source>Preferences...</source>
        <translation>Předvolby…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="248"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="249"/>
        <location filename="../qps.cpp" line="1666"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="335"/>
        <source>test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="336"/>
        <source>Copied to Clipboard</source>
        <translation>Zkopírováno do schránky</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="388"/>
        <source>context popup</source>
        <translation>kontextová vyskakovací nabídka</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="389"/>
        <source>Renice...</source>
        <translation>Změnit prioritu (nice)…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="390"/>
        <source>Scheduling...</source>
        <translation>Plánování…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Terminate</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="393"/>
        <source>Hangup</source>
        <translation>Terminál uzavřen (hangup)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="394"/>
        <source>Kill</source>
        <translation>Vynutit ukončení (kill)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="397"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="400"/>
        <source>Other Signals</source>
        <translation>Ostatní signály</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="401"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (přerušení)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="403"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (pokračovat)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="405"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (zastavit)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="407"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (ukončit)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="409"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (neplatná instrukce)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (přerušit)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="413"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (výjimka v plovoucí desetinné čárce)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="415"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (porušení ochrany paměti)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="417"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (neočekávané uzavření roury)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="419"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (signál časovače)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="421"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (uživatelem určený 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="423"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (uživatelem určený 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="425"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (podřízený proces ukončen)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="427"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (zastavení z konzole)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="429"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (vstup z konzole)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="431"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (výstup z konzole)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="438"/>
        <source>View Details</source>
        <translation>Zobrazit podrobnosti</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="676"/>
        <source>Show File Path</source>
        <translation>Zobrazit popis umístění souboru</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="682"/>
        <source>Show Graph</source>
        <translation>Zobrazit graf</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="688"/>
        <source>Show Control Bar</source>
        <translation>Zobrazit lištu ovládání</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="699"/>
        <source>Include Child Times</source>
        <translation>Zahrnout časy podřízených procesů</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="287"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1144"/>
        <location filename="../qps.cpp" line="1175"/>
        <location filename="../qps.cpp" line="1182"/>
        <location filename="../qps.cpp" line="1203"/>
        <location filename="../qps.cpp" line="1237"/>
        <location filename="../qps.cpp" line="1332"/>
        <source>Permission denied</source>
        <translation>Přístup odepřen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1145"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Nemáte oprávnění upravovat prioritu označených procesů (nice). To může udělat pouze vlastník procesu nebo správce systému.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1176"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Nemáte oprávnění upravovat prioritu procesu %1 (%2). To může udělat pouze vlastník procesu nebo správce systému.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1183"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Snížit prioritu procesu (nice) může pouze správce systému.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1204"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Pouze správce systému může měnit zásadu plánování a pevně danou prioritu.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1238"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Nemáte oprávnění měnit plánování a/nebo prioritu procesu %1 (%2). To může udělat pouze správce systému.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1299"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Opravdu chcete označené procesy ukončit?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1301"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Opravdu chcete „hang up“ označené procesy?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1303"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Opravdu chcete vynutit ukončení označených procesů?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1312"/>
        <source>Question</source>
        <translation>Dotaz</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1333"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Nemáte oprávnění poslat signál procesu %1 (%2). To může udělat pouze vlastník procesu nebo správce systému.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1682"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1684"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 – Vizuální správce procesů &lt;/h2&gt; %2 používá knihovnu Qt %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Zdrojové kódy: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Hlášení chyb: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1704"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Původní Qps vytvořil &lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Na vývoji se podíleli&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Změnit plánování</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Zásada plánování</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (sdílení času)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (v reálném čase)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (v reálném čase)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Priorita (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Neplatné zadání</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>Je třeba, aby priorita byla z rozsahu 1 až 99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation>IDENTIF. PROCESU, PŘÍKAZ, UŽIVATEL…</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>Filtrovat</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Změnit prioritu (nice) procesu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>Nová hodnota priority:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>Popisovač souboru</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protokol (TCP nebo UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Bajtů ve frontě příjmu</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Bajtů ve frontě odesílání</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>Místní adr.</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Místní IP adresa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Místní port</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>Vzdálená adr.</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>IP adresa protějšku</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Port na protějšku</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>Stav spojení</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>Počet procesů: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> Toto je nestabilní funkce v ranném stádiu vývoje
 Může vyvolávat porušení ochrany paměti…</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>titulek</translation>
    </message>
</context>
</TS>
